==> 9.2.19.tar.gz: scodoc/app/api/logos.py <==
# -*- mode: python -*-
# -*- coding: utf-8 -*-

##############################################################################
#
# Gestion scolarite IUT
#
# Copyright (c) 1999 - 2022 Emmanuel Viennet.  All rights reserved.
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
#   Emmanuel Viennet      emmanuel.viennet@viennet.net
#
##############################################################################

"""API: gestion des logos
Contrib @jmp
"""

from datetime import datetime
from flask import jsonify, g, send_file

from app.api import bp
from app.api import requested_format
from app.api.auth import token_auth
from app.api.errors import error_response
from app.models import Departement
from app.scodoc.sco_logos import list_logos, find_logo
from app.api.auth import token_auth, token_permission_required
from app.scodoc.sco_permissions import Permission


@bp.route("/logos", methods=["GET"])
@token_auth.login_required
@token_permission_required(Permission.APIView)
def api_get_glob_logos():
    if not g.current_user.has_permission(Permission.ScoSuperAdmin, None):
        return error_response(401, message="accès interdit")
    required_format = requested_format()  # json only
    if required_format is None:
        return error_response(400, "Illegal format")
    logos = list_logos()[None]
    return jsonify(list(logos.keys()))


@bp.route("/logos/<string:logoname>", methods=["GET"])
@token_auth.login_required
@token_permission_required(Permission.APIView)
def api_get_glob_logo(logoname):
    if not g.current_user.has_permission(Permission.ScoSuperAdmin, None):
        return error_response(401, message="accès interdit")
    logo = find_logo(logoname=logoname)
    if logo is None:
        return error_response(404, message="logo not found")
    logo.select()
    return send_file(
        logo.filepath,
        mimetype=f"image/{logo.suffix}",
        last_modified=datetime.now(),
    )


@bp.route("/departements/<string:departement>/logos", methods=["GET"])
@token_auth.login_required
@token_permission_required(Permission.APIView)
def api_get_local_logos(departement):
    dept_id = Departement.from_acronym(departement).id
    if not g.current_user.has_permission(Permission.ScoChangePreferences, departement):
        return error_response(401, message="accès interdit")
    logos = list_logos().get(dept_id, dict())
    return jsonify(list(logos.keys()))


@bp.route("/departements/<string:departement>/logos/<string:logoname>", methods=["GET"])
@token_auth.login_required
@token_permission_required(Permission.APIView)
def api_get_local_logo(departement, logoname):
    # format = requested_format("jpg", ['png', 'jpg']) XXX ?
    dept_id = Departement.from_acronym(departement).id
    if not g.current_user.has_permission(Permission.ScoChangePreferences, departement):
        return error_response(401, message="accès interdit")
    logo = find_logo(logoname=logoname, dept_id=dept_id)
    if logo is None:
        return error_response(404, message="logo not found")
    logo.select()
    return send_file(
        logo.filepath,
        mimetype=f"image/{logo.suffix}",
        last_modified=datetime.now(),
    )

==> 9.3.23.tar.gz: scodoc/app/api/logos.py <==
# -*- mode: python -*-
# -*- coding: utf-8 -*-

##############################################################################
#
# Gestion scolarite IUT
#
# Copyright (c) 1999 - 2022 Emmanuel Viennet.  All rights reserved.
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
#   Emmanuel Viennet      emmanuel.viennet@viennet.net
#
##############################################################################

"""API: gestion des logos
Contrib @jmp
"""

from datetime import datetime
from flask import jsonify, g, send_file
from flask_login import login_required

from app.api import api_bp as bp, api_web_bp
from app.api import requested_format
from app.api.errors import error_response
from app.models import Departement
from app.scodoc.sco_logos import list_logos, find_logo
from app.decorators import scodoc, permission_required
from app.scodoc.sco_permissions import Permission

# Note: l'API logos n'est accessible qu'en mode global (avec jeton, sans dept)


@bp.route("/logos")
@scodoc
@permission_required(Permission.ScoView)
def api_get_glob_logos():
    if not g.current_user.has_permission(Permission.ScoSuperAdmin, None):
        return error_response(401, message="accès interdit")
    required_format = requested_format()  # json only
    if required_format is None:
        return error_response(400, "Illegal format")
    logos = list_logos()[None]
    return jsonify(list(logos.keys()))


@bp.route("/logos/<string:logoname>")
@scodoc
@permission_required(Permission.ScoView)
def api_get_glob_logo(logoname):
    if not g.current_user.has_permission(Permission.ScoSuperAdmin, None):
        return error_response(401, message="accès interdit")
    logo = find_logo(logoname=logoname)
    if logo is None:
        return error_response(404, message="logo not found")
    logo.select()
    return send_file(
        logo.filepath,
        mimetype=f"image/{logo.suffix}",
        last_modified=datetime.now(),
    )


@bp.route("/departements/<string:departement>/logos")
@scodoc
@permission_required(Permission.ScoView)
def api_get_local_logos(departement):
    dept_id = Departement.from_acronym(departement).id
    if not g.current_user.has_permission(Permission.ScoChangePreferences, departement):
        return error_response(401, message="accès interdit")
    logos = list_logos().get(dept_id, dict())
    return jsonify(list(logos.keys()))


@bp.route("/departements/<string:departement>/logos/<string:logoname>")
@scodoc
@permission_required(Permission.ScoView)
def api_get_local_logo(departement, logoname):
    # format = requested_format("jpg", ['png', 'jpg']) XXX ?
    dept_id = Departement.from_acronym(departement).id
    if not g.current_user.has_permission(Permission.ScoChangePreferences, departement):
        return error_response(401, message="accès interdit")
    logo = find_logo(logoname=logoname, dept_id=dept_id)
    if logo is None:
        return error_response(404, message="logo not found")
    logo.select()
    return send_file(
        logo.filepath,
        mimetype=f"image/{logo.suffix}",
        last_modified=datetime.now(),
    )
